"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { getCountdownByRelationship } from "~/server/functions";
import { middleware } from "~/middleware";

export const GET = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { searchParams } = new URL(request.url);
    const relationshipId: string | null = searchParams.get("relationshipId");
    if (!relationshipId || isNaN(parseInt(relationshipId)))
      return NextResponse.json({ message: "Invalid relationshipId" }, { status: 400 });
    const countdown = await getCountdownByRelationship(parseInt(relationshipId));
    return NextResponse.json(countdown);
  } catch (error) {
    console.error(error);
    return NextResponse.json({ message: "Error" }, { status: 500 });
  }
};
