"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { getUserById } from "~/server/functions";
import { middleware } from "~/middleware";

export const GET = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const url = new URL(request.url);
    const userId = url.searchParams.get("userId");
    if (!userId || isNaN(parseInt(userId)))
      return NextResponse.json({ message: "Invalid userId" }, { status: 400 });
    const user = await getUserById(parseInt(userId));
    return NextResponse.json(user);
  } catch (error) {
    console.error(error);
    return NextResponse.json({ message: "Error" }, { status: 500 });
  }
};
