"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { updateUserPFP } from "~/server/functions";
import { middleware } from "~/middleware";

type UpdatePfpRequest = {
  userId: number;
  pfpURL: string;
}

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { userId, pfpURL } = await request.json() as UpdatePfpRequest;
    console.log("Received request:", { userId, pfpURL });

    if (!userId || !pfpURL || isNaN(userId))
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });

    console.log("Updating profile picture for user:", userId);
    const result = await updateUserPFP(userId, pfpURL);

    if (result.success) {
      console.log("Profile picture updated successfully");
      return NextResponse.json({ message: "Profile picture updated successfully" });
    } else {
      throw new Error("Failed to update profile picture");
    }
  } catch (error) {
    console.error("Error in updatePFP:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error updating profile picture" }, { status: 500 });
  }
}
