'use client';

import React, { useState } from 'react';

type MediaType = 'text' | 'image' | 'video' | 'audio' | 'file' | 'link';

export default function TestSendMessage() {
  const [senderId, setSenderId] = useState('');
  const [receiverId, setReceiverId] = useState('');
  const [content, setContent] = useState('');
  const [mediaType, setMediaType] = useState<MediaType | ''>('');
  const [mediaUrl, setMediaUrl] = useState('');
  const [result, setResult] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setResult(null);

    try {
      const response = await fetch('/api/messages/sendMessage', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'x-api-key': process.env.NEXT_PUBLIC_API_KEY ?? '',
        },
        body: JSON.stringify({
          senderId,
          receiverId,
          content,
          ...(mediaType && mediaUrl && { mediaType, mediaUrl }),
        }),
      });

      const data = await response.json() as {message: string}
      setResult(JSON.stringify(data, null, 2));
    } catch (error) {
      console.error('Error:', error);
      setResult('An error occurred');
    }
  };

  return (
    <main className="flex min-h-screen flex-col items-center justify-center
      bg-gradient-to-b from-pink-500 to-orange-400 text-white cursor-pointer">
      <div className="p-4">
        <h1 className="text-2xl mb-4">Test Send Message</h1>
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="senderId" className="block">Sender ID:</label>
            <input
              type="text"
              id="senderId"
              value={senderId}
              onChange={(e) => setSenderId(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="receiverId" className="block">Receiver ID:</label>
            <input
              type="text"
              id="receiverId"
              value={receiverId}
              onChange={(e) => setReceiverId(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="content" className="block">Content:</label>
            <textarea
              id="content"
              value={content}
              onChange={(e) => setContent(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="mediaType" className="block">Media Type:</label>
            <select
              id="mediaType"
              value={mediaType}
              onChange={(e) => setMediaType(e.target.value as MediaType)}
              className="border p-2 w-full bg-black"
            >
              <option value="">None</option>
              <option value="image">Image</option>
              <option value="video">Video</option>
              <option value="audio">Audio</option>
              <option value="file">File</option>
              <option value="link">Link</option>
            </select>
          </div>
          {mediaType && (
            <div>
              <label htmlFor="mediaUrl" className="block">Media URL:</label>
              <input
                type="text"
                id="mediaUrl"
                value={mediaUrl}
                onChange={(e) => setMediaUrl(e.target.value)}
                className="border p-2 w-full bg-black"
                required
              />
            </div>
          )}
          <button type="submit" className="bg-blue-500 text-white p-2 rounded">
            Send Message
          </button>
        </form>
        {result && (
          <div className="mt-4 p-2 rounded bg-black">
            <pre>{result}</pre>
          </div>
        )}
      </div>
    </main>
  );
}
