"use client";

import React, { useState } from 'react';

export default function CreateUserPage() {
  const [appleId, setAppleId] = useState("");
  const [appleEmail, setAppleEmail] = useState("");
  const [fullName, setFullName] = useState("");
  const [pushToken, setPushToken] = useState("");
  const [pfpURL, setPfpURL] = useState("");
  const [result, setResult] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setResult(null);

    try {
      const response = await fetch('/api/users/createUser', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'x-api-key': process.env.NEXT_PUBLIC_API_KEY ?? '',
        },
        body: JSON.stringify({
          appleId,
          appleEmail,
          fullName,
          pfpURL,
          pushToken
        })
      });
      const data = await response.json() as {message: string}
      setResult(JSON.stringify(data, null, 2));
    } catch (error) {
      console.error('Error:', error);
      setResult('An error occurred');
    }
  };

  return (
    <main className="flex min-h-screen flex-col items-center justify-center
      bg-gradient-to-b from-pink-500 to-orange-400 text-white cursor-pointer">
      <div className="p-4">
        <h1 className="text-2xl mb-4">Test Create User</h1>
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="appleId" className="block">Apple ID:</label>
            <input
              type="text"
              id="appleId"
              value={appleId}
              onChange={(e) => setAppleId(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="appleEmail" className="block">Apple Email:</label>
            <input
              type="text"
              id="appleEmail"
              value={appleEmail}
              onChange={(e) => setAppleEmail(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="fullName" className="block">Full Name:</label>
            <input
              type="text"
              id="fullName"
              value={fullName}
              onChange={(e) => setFullName(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="pfpURL" className="block">Pfp URL:</label>
            <input
              type="text"
              id="pfpURL"
              value={pfpURL}
              onChange={(e) => setPfpURL(e.target.value)}
              className="border p-2 w-full bg-black"
            />
          </div>
          <div>
            <label htmlFor="pushToken" className="block">Push Token:</label>
            <input
              type="text"
              id="pushToken"
              value={pushToken}
              onChange={(e) => setPushToken(e.target.value)}
              className="border p-2 w-full bg-black"
            />
          </div>
          <button type='submit' className='bg-blue-500 p-2 rounded'>
            Create User
          </button>
        </form>
        {result && (
          <div className='mt-4 p-2 rounded bg-black'>
            <pre>{result}</pre>
          </div>
        )}
      </div>
    </main>
  );
};
